pub fn load_server_state(path: impl AsRef<Path>) -> ServerResult<ServerState>Expand description
Loads a TOML deployment file and constructs the complete server state.
pub fn load_server_state(path: impl AsRef<Path>) -> ServerResult<ServerState>Loads a TOML deployment file and constructs the complete server state.