pub fn initialize_observability() -> ServerResult<()>Expand description
Installs metrics and tracing once for either the binary or an embedded host.
pub fn initialize_observability() -> ServerResult<()>Installs metrics and tracing once for either the binary or an embedded host.